Reahl
=====

Reahl is a web application framework that allows a programmer to work
in terms of useful abstractions—using a single programming language.

The details of how those abstractions are implemented using several
different web technologies are hidden and dealt with for the
programmer.

More details at our website: [Reahl - the Python-only web framework](http://www.reahl.org)
